from .mathtable import MathTable
from .styles import styledchr, styledstr
from .zmath import Math, Text, set_precision

__version__ = '0.5'